import maya.OpenMayaUI as apiUI
from mg.widgets.Qt import QtCore, QtGui, QtUiTools, QtWidgets

try:
    import shiboken
except:
    import shiboken2 as shiboken


def get_maya_window():
    ptr = apiUI.MQtUtil.mainWindow()
    if ptr is not None:
        return shiboken.wrapInstance(long(ptr), QtWidgets.QWidget)


class Window(QtWidgets.QWidget):

    resizeEvt = QtCore.Signal()

    def __init__(self, parent):
        super(Window, self).__init__(self._parent)
        self.setWindowFlags(QtCore.Qt.Window)
        self._parent = parent
        self.layout = QtWidgets.QVBoxLayout(self)
        self.layout.setSpacing(0)
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.setContentsMargins(0, 0, 0, 0)
        self.window = None
        self.uiFilePath = None

    def load_ui(self, ui_file_path):
        self.uiFilePath = ui_file_path
        loader = QtUiTools.QUiLoader()
        ui_file = QtCore.QFile(ui_file_path)
        ui_file.open(QtCore.QFile.ReadOnly)
        self.window = loader.load(ui_file)
        ui_file.close()
        self.layout.addWidget(self.window)
        self.window.setContentsMargins(0, 0, 0, 0)

    def resizeEvent(self, event):
        self.resizeEvt.emit()

    def save_geometry(self, geometry_name):
        settings_obj = QtCore.QSettings(QtCore.QSettings.UserScope, "Myriad Grains", "Myriad Grains")
        settings_obj.setValue(geometry_name, self.saveGeometry())

    def setup_gui(self):
        raise NotImplementedError
